unit Lptcombo;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Menus, ComAbout, DsgnIntf;

type
  TLPTCombo = class(TCustomComboBox)
  private
    { Private declarations }
    LPTAddress: array[1..3] of Word;
    FPortAddress: Word;
    FFullPortName: Boolean;
    FAbout: string;
    procedure DrawCombo;
    procedure SetWord(Value: Word);
    procedure SetFullPortName(Value: Boolean);
  protected
    { Protected declarations }
    {$IFDEF WIN32}
    procedure ValidateRename(AComponent: TComponent; const CurName, NewName: string);  override;
    {$ENDIF}
    procedure CreateWnd; override;
  public
    { Public declarations }
    procedure Change; override;
    constructor Create(AOwner: TComponent); override;
  published
    { Published declarations }
    property PortAddress: Word read FPortAddress write SetWord;
    property FullPortName: Boolean read FFullPortName write SetFullPortName;

    property Color;
    property Ctl3D;
    property DragCursor;
    property DragMode;
    property Enabled;
    property Font;
    property Hint;
    property ParentColor;
    property ParentCtl3D;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property TabOrder;
    property Visible;

    property OnChange;
    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnDropDown;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;

    property About: string read FAbout write FAbout;
  end;


        { AboutTypeProperty }

type
  TAboutTypeProperty = class(TPropertyEditor)
  private

  public
     function GetValue: string; override;
     procedure SetValue(const Value: string); override;
     procedure Edit; override;
     function GetAttributes: TPropertyAttributes; override;
  end;

var
   AboutLPTCombo: TAboutComponent;


procedure Register;
procedure RunAboutBox;

implementation


procedure Register;
begin
  RegisterComponents('BealeARTS', [TLPTCombo]);
  RegisterPropertyEditor(TypeInfo(string), TLPTCombo, 'About', TAboutTypeProperty);
end;



{$IFDEF WIN32}
procedure TLPTCombo.ValidateRename(AComponent: TComponent;
  const CurName, NewName: string);
begin
  if (AComponent <> nil) and (CompareText(CurName, NewName) <> 0) and
    (FindComponent(NewName) <> nil) then
    raise EComponentError.CreateFmt('A component named %s already exists.', [NewName]);
end;
{$ENDIF}



constructor TLPTCombo.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);

Style := csDropDownList;
FFullPortName := True;

end;



procedure TLPTCombo.CreateWnd;
begin
  inherited CreateWnd;

DrawCombo;
ItemIndex := 0;
FPortAddress := LPTAddress[1];

end;



procedure TLPTCombo.DrawCombo;
var
   Count, SaveIndex: Byte;
begin

SaveIndex := ItemIndex;
Items.Clear;

for Count := 1 to 3 do
    if (mem[$0040:$06+(Count*2)] + mem[$0040:$07+(Count*2)]*256) <> 0 then
    begin
    if FFullPortName then Items.Add('Parallel Port LPT' + IntToStr(Count))
       else Items.Add('LPT' + IntToStr(Count));
    LPTAddress[Items.Count] := mem[$0040:$06+(Count*2)] + mem[$0040:$07+(Count*2)]*256;
    end;

ItemIndex := SaveIndex;

ReFresh;

end;



procedure TLPTCombo.Change;
begin

FPortAddress := LPTAddress[ItemIndex+1];

  Inherited Change;
end;



procedure TLPTCombo.SetWord(Value: Word);
begin
end;



procedure TLPTCombo.SetFullPortName(Value: Boolean);
begin
FFullPortName := Value;
DrawCombo;
end;



procedure RunAboutBox;
begin
 { Create dialog in memory }
     AboutLPTCombo := TAboutComponent.Create(Application);

     { Set dialog strings }
     AboutLPTCombo.ProductName.Caption := 'LPTCombo';
     AboutLPTCombo.Caption := 'About LPTCombo';
     AboutLPTCombo.Copyright.Caption := 'Copyright 1998, David Beale';

AboutLPTCombo.Memo.Lines.Add('Properties');
AboutLPTCombo.Memo.Lines.Add('_______________________________________________');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('About - String');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Displays this about dialog. Performs no function when set from within your code.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Color - TColor');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Background color of the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Ctl3D - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines whether a control has a three-dimensional (3-D) or two-dimensional look.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Cursor - TCursor');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Cursor used by control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('DragCursor - TCursor');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Cursor used when dragging.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('DragMode - TDragMode');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines the drag and drop behavior of a control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Enabled - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Controls whether the control responds to mouse, keyboard, and timer events.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Font - TFont');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Controls the attributes of text written on or in the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('FullPortName - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines whether the full port name is used.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Height - Integer');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Vertical size of the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('HelpContext - THelpContext');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Context number for use in calling context-sensitive online Help.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Hint - String');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Control hint message.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Left - Integer');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Horizontal coordinate of the left edge of the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Name - String');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Name of this component, ie LPTCombo1.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('ParentColor - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines where the control looks for its color information.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('ParentCtl3D - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines where the control looks for its Ctl3D information.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('ParentFont - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines where the control looks for its Font information.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('ParentShowHint - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines where the control looks to find out if Help Hint should be show.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('PopupMenu - TPopupMenu');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Identifies the name of the control''s pop-up menu.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('PortAddress - Word');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Address of the selected LPT port.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('ShowHint - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines if the control should display a Help Hint.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('TabOrder - TTabOrder');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Indicates the position of the control in its parent''s tab order.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('TabStop - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines if the user can tab to a control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Tag - LongInt');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Components Tag.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Top - Integer');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Vertical coordinate of the top edge of the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Visible - Boolean');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Determines whether the control appears onscreen.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Width - Integer');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Horizontal size of the control.');

AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Events');
AboutLPTCombo.Memo.Lines.Add('_______________________________________________');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnChange - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the control changes.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnClick - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the user clicks the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnDblClick - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the user double-clicks the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnDragDrop - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the user drops an object being dragged.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnDragOver - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the user drags an object over the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnDropDown - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the user opens (drops down) the control.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnEndDrag - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs whenever the dragging of an object ends.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnEnter - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when a control becomes active.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnExit - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the input focus shifts away from the control to another.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnKeyDown - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when a user presses any key while the control has focus.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnKeyPress - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when a user presses a single character key.');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('OnKeyUp - TNotifyEvent');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Occurs when the user releases a key that has been pressed.');

AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('');
AboutLPTCombo.Memo.Lines.Add('Methods');
AboutLPTCombo.Memo.Lines.Add('_______________________________________________');
AboutLPTCombo.Memo.Lines.Add('');


  { Set result to OK }
    AboutLPTCombo.Icon := Application.Icon;
    AboutLPTCombo.ShowModal;

AboutLPTCombo.Free
end;



function TAboutTypeProperty.GetValue: string;
begin
Result := 'LPTCombo';
end;

procedure TAboutTypeProperty.SetValue(const Value: string);
begin
RunAboutBox;
end;

procedure TAboutTypeProperty.Edit;
begin
RunAboutBox;
end;

function TAboutTypeProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;



end.
